==> portal-contribuinte-3.326.0.zip: BOOT-INF/classes/br/com/elotech/tributos/repository/find-debito-geracao-cda-avulsa.sql <==
Select distinct
        coalesce(liv.Sequencia,0) Sequencia,
        tdp.TipoCadastro,
        tdp.CadastroGeral,
        tdp.ExercicioLivro,
        tdp.livro,
        tdp.entidade,
        td.exercicio,
        tdp.GuiaRecolhimento,
        tdp.Exercicio ExercicioDebito,
        tdp.SubDivida,
        tdpr.Receita,
        tdp.Parcela,
        tdpr.Valor,
        cg.Pessoa,
        0.00 as ValorJuros,
        0.00 as ValorMulta,
        0.00 as ValorCorrecao,
        tdp.NumeroInscricao,
        tdp.NumeroFolha,
        tdp.DataLancamento,
        td.DataPrimeiraParcela,
        tdp.DataVencimento,
        td.FormaCorrecao,
        td.Parcelado,
        tdp.SituacaoLegal,
        tgr.idkey as dividaId,
        tgr.apelido,
        tgr.Descricao as descricaoGuia,
        tgr.tipoguiarecolhimento,
        tgr.inativa
      from  tribDebitoParcelaReceita tdpr
      left outer join tribDebitoParcela tdp on tdpr.entidade = tdp.entidade
                                           and tdpr.Exercicio = tdp.Exercicio
                                           and tdpr.TipoCadastro = tdp.TipoCadastro
                                           and tdpr.CadastroGeral = tdp.CadastroGeral
                                           and tdpr.GuiaRecolhimento = tdp.GuiaRecolhimento
                                           and tdpr.SubDivida = tdp.SubDivida
                                           and tdpr.Parcela = tdp.Parcela
      left outer join tribDebito td on tdpr.entidade = td.entidade
                                   and tdpr.Exercicio = td.Exercicio
                                   and tdpr.TipoCadastro = td.TipoCadastro
                                   and tdpr.CadastroGeral = td.CadastroGeral
                                   and tdpr.GuiaRecolhimento = td.GuiaRecolhimento
                                   and tdpr.SubDivida = td.SubDivida
      left outer join TribSituacaoParcela tsp on tsp.SituacaoParcela = tdp.SituacaoDebito
      left outer join tribCadastroGeral cg on td.TipoCadastro = cg.TipoCadastro
                                          and td.CadastroGeral = cg.CadastroGeral
      left outer join TribLivroParcelaReceita livr on
                                       tdpr.IDDebitoParcelaReceita = livr.IDDebitoParcelaReceita
      left outer join TribLivroRegistro liv on livr.Entidade = liv.Entidade
                                   and livr.Exercicio = liv.Exercicio
                                   and livr.Livro = liv.Livro
                                   and livr.sequencia = liv.Sequencia
      left outer join TribGuiaRecolhimento tgr
                   on td.Entidade = tgr.Entidade and
                      td.Exercicio = tgr.Exercicio and
                      td.GuiaRecolhimento = tgr.GuiaRecolhimento
      left outer join Pessoa p on
                      cg.Pessoa = p.Pessoa
     where td.Entidade = :entidade
     and tdp.situacaolegal in ( 1, 2 )
     and tsp.TipoSituacaoparcela = 1
     $[FILTROS]

==> portal-contribuinte-4.106.0.zip: BOOT-INF/classes/br/com/elotech/tributos/repository/find-debito-geracao-cda-avulsa.sql <==
Select distinct
        coalesce(liv.Sequencia,0) Sequencia,
        tdp.TipoCadastro,
        tdp.CadastroGeral,
        tdp.ExercicioLivro,
        tdp.livro,
        tdp.entidade,
        td.exercicio,
        tdp.GuiaRecolhimento,
        tdp.Exercicio ExercicioDebito,
        tdp.SubDivida,
        tdpr.Receita,
        tdp.Parcela,
        tdpr.Valor,
        cg.Pessoa,
        0.00 as ValorJuros,
        0.00 as ValorMulta,
        0.00 as ValorCorrecao,
        tdp.NumeroInscricao,
        tdp.NumeroFolha,
        tdp.DataLancamento,
        td.DataPrimeiraParcela,
        td.dataCorrecaoIgpm,
        tdp.DataVencimento,
        td.FormaCorrecao,
        td.Parcelado,
        tdp.SituacaoLegal,
        tgr.idkey as dividaId,
        tgr.apelido,
        tgr.Descricao as descricaoGuia,
        tgr.tipoguiarecolhimento,
        tgr.inativa
      from  tribDebitoParcelaReceita tdpr
      left outer join tribDebitoParcela tdp on tdpr.entidade = tdp.entidade
                                           and tdpr.Exercicio = tdp.Exercicio
                                           and tdpr.TipoCadastro = tdp.TipoCadastro
                                           and tdpr.CadastroGeral = tdp.CadastroGeral
                                           and tdpr.GuiaRecolhimento = tdp.GuiaRecolhimento
                                           and tdpr.SubDivida = tdp.SubDivida
                                           and tdpr.Parcela = tdp.Parcela
      left outer join tribDebito td on tdpr.entidade = td.entidade
                                   and tdpr.Exercicio = td.Exercicio
                                   and tdpr.TipoCadastro = td.TipoCadastro
                                   and tdpr.CadastroGeral = td.CadastroGeral
                                   and tdpr.GuiaRecolhimento = td.GuiaRecolhimento
                                   and tdpr.SubDivida = td.SubDivida
      left outer join TribSituacaoParcela tsp on tsp.SituacaoParcela = tdp.SituacaoDebito
      left outer join tribCadastroGeral cg on td.TipoCadastro = cg.TipoCadastro
                                          and td.CadastroGeral = cg.CadastroGeral
      left outer join TribLivroParcelaReceita livr on
                                       tdpr.IDDebitoParcelaReceita = livr.IDDebitoParcelaReceita
      left outer join TribLivroRegistro liv on livr.Entidade = liv.Entidade
                                   and livr.Exercicio = liv.Exercicio
                                   and livr.Livro = liv.Livro
                                   and livr.sequencia = liv.Sequencia
      left outer join TribLivro li on li.Entidade = liv.Entidade
                                         and li.Exercicio = liv.Exercicio
                                         and li.Livro = liv.Livro
      left outer join TribGuiaRecolhimento tgr
                   on td.Entidade = tgr.Entidade and
                      td.Exercicio = tgr.Exercicio and
                      td.GuiaRecolhimento = tgr.GuiaRecolhimento
      left outer join Pessoa p on
                      cg.Pessoa = p.Pessoa
     where td.Entidade = :entidade
     and tdp.situacaolegal in ( 1, 2 )
     and tsp.TipoSituacaoparcela = 1
     and li.tipolivro = 'EFETIVO'
     $[FILTROS]
